@@ -1,11 +1,13 @@
 package WWW::Pocket;
 our $AUTHORITY = 'cpan:DOY';
-$WWW::Pocket::VERSION = '0.02';
+$WWW::Pocket::VERSION = '0.03';
 use Moose;
 # ABSTRACT: Wrapper for the Pocket v3 API
 
 use HTTP::Tiny;
+use IO::Socket::SSL; # Necessary for https URLs on HTTP::Tiny.
 use JSON::PP;
+use Carp;
 
 
 
@@ -154,7 +156,7 @@ sub _request {
             },
         },
     );
-    die "Request for $uri failed ($response->{status}): $response->{reason}"
+    croak "Request for $uri failed ($response->{status}): $response->{content}"
         unless $response->{success};
 
     return decode_json($response->{content});
@@ -178,7 +180,7 @@ WWW::Pocket - Wrapper for the Pocket v3 API
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -327,7 +329,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Jesse Luehrs.
+This software is Copyright (c) 2016 by Jesse Luehrs.
 
 This is free software, licensed under:
 
