@@ -1,6 +1,6 @@
 package WWW::Pocket::Script;
 our $AUTHORITY = 'cpan:DOY';
-$WWW::Pocket::Script::VERSION = '0.02';
+$WWW::Pocket::Script::VERSION = '0.03';
 use Moose;
 
 use Getopt::Long 'GetOptionsFromArray';
@@ -8,6 +8,7 @@ use JSON::PP;
 use List::Util 'sum';
 use Path::Class;
 use URI;
+use Pod::Usage;
 
 use WWW::Pocket;
 
@@ -57,7 +58,7 @@ sub run {
         return $self->$method(@argv);
     }
     else {
-        die "insert usage here";
+        pod2usage(-verbose => 2);
     }
 }
 
@@ -65,6 +66,7 @@ sub _method_is_command {
     my $self = shift;
     my ($name) = @_;
 
+    return unless $name;
     return if $name eq 'run' || $name eq 'meta';
     return if $name =~ /^_/;
     my $method = $self->meta->find_method_by_name($name);
@@ -74,6 +76,20 @@ sub _method_is_command {
     return 1;
 }
 
+# Display quick usage help on this script.
+sub help {
+    my $self = shift;
+    pod2usage(-verbose => 1);
+}
+
+# Display comprehensive help about this script.
+sub man {
+    my $self = shift;
+    pod2usage(-verbose => 2);
+}
+
+
+
 sub authenticate {
     my $self = shift;
     $self->pocket;
@@ -120,8 +136,16 @@ sub _authenticate {
 sub _prompt_for_consumer_key {
     my $self = shift;
 
+    print "Consumer key required. You can sign up for a consumer key as a\n" .
+        "Pocket developer at https://getpocket.com/developer/apps/new.\n";
+
     print "Enter your consumer key: ";
-    chomp(my $key = <STDIN>);
+    my $key = <STDIN>;
+
+    # Trim start and end.
+    $key =~ s/^\s*(.*)\s*$/$1/;
+    # print "Key entered: '$key'\n";
+
     return $key;
 }
 
@@ -378,7 +402,9 @@ no Moose;
   delete
   favorite
   favorites
+  help
   list
+  man
   readd
   retrieve_raw
   run
